package WebGUI::i18n::German::Asset_Post;
use utf8;
our $I18N = {
  523 => {
    'lastUpdated' => '1179831029',
    'message' => 'Benachrichtigung'
  },
  875 => {
    'lastUpdated' => '1179831075',
    'message' => 'Eine neue Nachricht in einem ihrer Abonnements wurde gepostet.'
  },
  'By' => {
    'lastUpdated' => '1157856308',
    'message' => 'von'
  },
  'Edited_on' => {
    'lastUpdated' => '1277325454',
    'message' => 'Bearbeitet am'
  },
  'Skip notification' => {
    'lastUpdated' => '1269421925',
    'message' => 'E-Mail-Benachrichtigung überspringen.'
  },
  'add/edit post template title' => {
    'lastUpdated' => '1179831165',
    'message' => 'Post Hinzufügen/Bearbeiten Template'
  },
  'approved' => {
    'lastUpdated' => '1179831179',
    'message' => 'Freigegeben'
  },
  'archive.form' => {
    'lastUpdated' => '1179831256',
    'message' => 'Eine Ja/Nein Schaltfläche für das Archivieren des Threads, wenn Sie diese Antwort abschicken. Diese ist nur f&uuml;r Moderatoren verf&uuml;gbar.'
  },
  'archived' => {
    'lastUpdated' => '1179831262',
    'message' => 'Archiviert'
  },
  'assetName' => {
    'lastUpdated' => '1179831266',
    'message' => 'Post'
  },
  'assetSize' => {
    'lastUpdated' => '1179831317',
    'message' => 'Die formatierte Größe dieses Posts.'
  },
  'attachment.form' => {
    'lastUpdated' => '1179831564',
    'message' => 'Kode, der es erlaubt, Anhänge zu Posts hinzuzufügen.'
  },
  'attachment.icon' => {
    'lastUpdated' => '1179831588',
    'message' => 'Icon, das den Dateityp des Anhangs anzeigt.'
  },
  'attachment.name' => {
    'lastUpdated' => '1179831609',
    'message' => 'Der Name des ersten Anhangs, der im Post gefunden wurde.'
  },
  'attachment.url' => {
    'lastUpdated' => '1179831625',
    'message' => 'URL, um den ersten Anhang des Posts runterzuladen.'
  },
  'attachment_loop' => {
    'lastUpdated' => '1179831835',
    'message' => 'Schleife, die alle Datei- und Bildanhänge dieses Posts enth&auml;lt.'
  },
  'avatar.url' => {
    'lastUpdated' => '1179831900',
    'message' => 'URL zum Avatar des Besitzers des Posts, falls Avatare im übergeordneten Collaboration System aktiviert sind und der Benuzter ein Avatar besitzt.'
  },
  'content' => {
    'lastUpdated' => '1179831912',
    'message' => 'Der Inhalt oder Body eines Posts.'
  },
  'content.form' => {
    'lastUpdated' => '1179832012',
    'message' => 'Feld für die Bearbeitung des Inhalts (Makros deaktiviert). Falls das Discussion Board "rich content" erlaubt, so handelt es sich hierbei um einen WYSIWYG HTML Bereich. Andernfalls handelt es sich um einen plain text Bereich.'
  },
  'contentType' => {
    'lastUpdated' => '1179832101',
    'message' => 'Typ des Inhalts des Posts, typischerweise &quot;kode&quot;, &quot;Text&quot;, &quot;HTML&quot;, &quot;gemischt&quot;.'
  },
  'contentType.form' => {
    'lastUpdated' => '1179832094',
    'message' => 'Formularfeld, das beschreibt, wie der Inhalt des Posts formatiert ist. HTML, Text, Kode oder gemischt. Standard ist gemischt.'
  },
  'dateSubmitted' => {
    'lastUpdated' => '1179832123',
    'message' => 'Datum, an dem der Post abgeschickt wurde, im "epoch" Format.'
  },
  'dateSubmitted.human' => {
    'lastUpdated' => '1179832146',
    'message' => 'Datum, an dem der Post abgeschickt wurde, im "human-readable" Format.'
  },
  'dateUpdated' => {
    'lastUpdated' => '1179832184',
    'message' => 'Datum, an dem der Post zuletzt aktualisiert wurde, im "epoch" Format.'
  },
  'dateUpdated.human' => {
    'lastUpdated' => '1179833218',
    'message' => 'Datum, an dem der Post zuletzt aktualisiert wurde, im "human-readable" Format.'
  },
  'delete.url' => {
    'lastUpdated' => '1179833231',
    'message' => 'URL, um den Post zu löschen.'
  },
  'edit.url' => {
    'lastUpdated' => '1179833246',
    'message' => 'URL, um den Post zu bearbeiten.'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1179833276',
    'message' => 'Extra HTML Header Tags.'
  },
  'field' => {
    'lastUpdated' => '1193133301',
    'message' => 'Das Formular für das Metadata Feld'
  },
  'filename' => {
    'lastUpdated' => '1179833286',
    'message' => 'Der Name des Anhangs.'
  },
  'form.cancel' => {
    'lastUpdated' => '1270627878',
    'message' => 'Ein Button um die Nachricht abzubrechen.'
  },
  'form.footer' => {
    'lastUpdated' => '1179833304',
    'message' => 'Kode für das Ende des Formulars.'
  },
  'form.header' => {
    'lastUpdated' => '1179833332',
    'message' => 'Kode, der zum Start des Formulars für den Post vorausgesetzt wird.'
  },
  'form.preview' => {
    'lastUpdated' => '1179833355',
    'message' => 'Eine Schaltfläche für die Post Vorschau.'
  },
  'form.submit' => {
    'lastUpdated' => '1179833373',
    'message' => 'Eine Schaltfläche, um den Post abzuschicken (Submit).'
  },
  'formatted.content' => {
    'lastUpdated' => '1179833896',
    'message' => 'Der formatierte und gefilterte Inhalt des Posts, falls ein Thread, der den Post enthält, existiert. Diese Variable überschreibt jede andere Variable mit diesem Namen in der Liste der Template Variablen.'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1179833919',
    'message' => 'Die ID der Gruppe, deren Mitglieder den Post editieren dürfen.'
  },
  'groupIdView' => {
    'lastUpdated' => '1179833937',
    'message' => 'Die ID der Gruppe, deren Mitglieder den Post ansehen dürfen.'
  },
  'hasRated' => {
    'lastUpdated' => '1179834123',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer diesen Post schon bewertet hat.'
  },
  'help url.raw' => {
    'lastUpdated' => '1215072862',
    'message' => 'Die URL zum Post Asset ohne #id am Ende. Hilfreich um andere Funktionen des Posts auszuführen, z.B. func=promote oder func=demote.'
  },
  'icon' => {
    'lastUpdated' => '1179834141',
    'message' => 'Icon, das den Dateityp dieses Anhangs darstellt.'
  },
  'image.thumbnail' => {
    'lastUpdated' => '1179834198',
    'message' => 'Ein Thumbnail des Bildes, das dem Post angehängt ist.'
  },
  'image.url' => {
    'lastUpdated' => '1179834215',
    'message' => 'URL zum ersten Bild, das dem Post angehängt ist.'
  },
  'isEdit' => {
    'lastUpdated' => '1179834247',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer einen existierenden Post bearbeitet.'
  },
  'isHidden' => {
    'lastUpdated' => '1179834271',
    'message' => 'Bedingung, die angibt, ob dieser Post von der Navigation verborgen ist.'
  },
  'isImage' => {
    'lastUpdated' => '1179834293',
    'message' => 'Bedingung, die angibt, ob dieser Anhang ein Bild ist.'
  },
  'isNewPost' => {
    'lastUpdated' => '1179834335',
    'message' => 'Bedingung, die wahr ist, falls der Benuzter einen neuen Post hinzufügt. Gegenteil vom Bearbeiten eines schon existierenden Posts.'
  },
  'isNewThread' => {
    'lastUpdated' => '1278344415',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer einen neuen Thread hinzufügt.'
  },
  'isPackage' => {
    'lastUpdated' => '1179834378',
    'message' => 'Bedingung, die anzeigt, ob dieser Post ein Paket ist.'
  },
  'isPrototype' => {
    'lastUpdated' => '1179834399',
    'message' => 'Bedingung, die anzeigt, ob dieser Post ein Inhaltsprototyp ist.'
  },
  'isReply' => {
    'lastUpdated' => '1278344369',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer auf einen existierenden Post antwortet.'
  },
  'isSubscribedToCs' => {
    'lastUpdated' => '1278344547',
    'message' => 'Ein boolscher Wert, der wahr ist, falls der aktuelle Benutzer das CS mit diesem Beitrag abonniert hat.'
  },
  'isThread' => {
    'lastUpdated' => '1179834473',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer einen Hauptpost eines Threads bearbeitet. Gegenteil zu einer Antwort in einem Thread.'
  },
  'karmaIsEnabled' => {
    'lastUpdated' => '1179834557',
    'message' => 'Bedingung, die wahr ist, falls Karma in den Einstellungen aktiviert ist'
  },
  'karmaScale.form' => {
    'lastUpdated' => '1179837791',
    'message' => 'Formular Element, das es Moderatoren erlaubt, die Anzeige eines einzelnen Threads zu ändern. Dies ist nur verfügbar f&uuml;r Threads.'
  },
  'keywords.form' => {
    'lastUpdated' => '1344184514',
    'message' => 'Ein Texteingabefeld für Schlüsselworte'
  },
  'lock.form' => {
    'lastUpdated' => '1179834692',
    'message' => 'Eine Ja/Nein Schaltfläche, um den Thread zu sperren. Falls gesperrt, können keine weiteren Post hinzugefügt bzw. bestehende Posts bearbeitet werden.'
  },
  'menuTitle' => {
    'lastUpdated' => '1179834737',
    'message' => 'Der Menütitel des Posts, oft genutzt in der Navigation.'
  },
  'meta_X_form' => {
    'lastUpdated' => '1217255086',
    'message' => 'Das Formular für ein bestimmtes Metadatenfeld, ausgewählt nach dem Namen. X ist der Name des Metadatenfeldes, wobei alle Leerzeichen im Namen durch Unterstricke erstetzt wurden.'
  },
  'meta_X_value' => {
    'lastUpdated' => '1217255127',
    'message' => 'Der Wert eines bestimmten Metadatenfeldes, ausgewählt nach dem Namen. X ist der Name des Metadatenfeldes, wobei alle Leerzeichen im Namen durch Unterstricke erstetzt wurden.'
  },
  'meta_loop' => {
    'lastUpdated' => '1215073328',
    'message' => 'Eine Schleife die Metadaten Beschriftungen und Felder dieser Nachricht enthält. Wenn Metadaten deaktiviert oder nicht vorhanden sind, werden keine Daten angezeigt.'
  },
  'name' => {
    'lastUpdated' => '1215073184',
    'message' => 'Die Beschriftung für dieses Metadaten Feld. Metadaten Beschriftungen werden nicht &uuml;bersetzt.'
  },
  'new file description' => {
    'lastUpdated' => '1179834822',
    'message' => 'Geben Sie den Pfad der Datei ein oder benutzen Sie die "Browse" Schaltfläche, um eine Datei auf ihrer Festplatte zu suchen, die Sie auf das System hochladen wollen.'
  },
  'newWindow' => {
    'lastUpdated' => '1179834849',
    'message' => 'Bedingung, die angibt, ob dieser Post in einem neuen Fenster geöffnet werden soll.'
  },
  'notification template body' => {
    'lastUpdated' => '1179834890',
    'message' => 'Zusätzlich zu den allgemeinen Post Template Variablen besitzt das Benachrichtung Template diese Variablen:'
  },
  'notification template title' => {
    'lastUpdated' => '1179834899',
    'message' => 'Benachrichtigung Template'
  },
  'notify url' => {
    'lastUpdated' => '1179834998',
    'message' => 'URL zum Post, der die Benachrichtigung ausgelöst hat.'
  },
  'notify.subscription.message' => {
    'lastUpdated' => '1277325503',
    'message' => 'Internationalisierte Nachricht über eine neue Nachricht zu einem vom Benutzer abonnierten Thema.'
  },
  'ownerUserId' => {
    'lastUpdated' => '1179835012',
    'message' => 'Ein Alias für userId.'
  },
  'pending' => {
    'lastUpdated' => '1179835022',
    'message' => 'Schwebend'
  },
  'post asset variables title' => {
    'lastUpdated' => '1179835080',
    'message' => 'Post Asset Template Variablen'
  },
  'post received' => {
    'lastUpdated' => '1286874142',
    'message' => 'Ihre Nachricht wurde entgegengenommen und wird zurzeit verarbeitet, damit diese zur Site hinzugefügt werden kann. Bitte haben Sie ein wenig Geduld.'
  },
  'post template variables title' => {
    'lastUpdated' => '1277325573',
    'message' => 'Post Template Variablen'
  },
  'preview.content' => {
    'lastUpdated' => '1179835102',
    'message' => 'Der Inhalt, wenn die Vorschau auf einen Post angezeigt wird.'
  },
  'preview.synopsis' => {
    'lastUpdated' => '1179835278',
    'message' => 'Zusammenfassung bei der Vorschau eines Posts. Falls keine Zusammenfassung angegeben wurde, wird versucht, eine Zusammenfassung aus dem Text der Beschreibung bis zum ^-; Marker zu generieren. Falls kein Marker gefunden werden kann, wird der Text bis zur ersten neuen Zeile benutzt.'
  },
  'preview.title' => {
    'lastUpdated' => '1179835298',
    'message' => 'Der Titel der Vorschau des Posts.'
  },
  'preview.userDefinedN' => {
    'lastUpdated' => '1179835371',
    'message' => 'Der Inhalt von benutzerdefinierten Feldern des Posts; WebGUI Makros werden nicht verarbeitet; N geht von 1 bis 5.'
  },
  'rate.url.thumbsDown' => {
    'lastUpdated' => '1179835385',
    'message' => 'Eine negative Bewertung.'
  },
  'rate.url.thumbsUp' => {
    'lastUpdated' => '1179835397',
    'message' => 'Eine positive Bewertung.'
  },
  'rating' => {
    'lastUpdated' => '1179835846',
    'message' => 'Ein anderer Name für <strong>rating.value</strong>'
  },
  'rating.value' => {
    'lastUpdated' => '1179835864',
    'message' => 'Die aktuelle Bewertung für diesen Post.'
  },
  'relativeUrl' => {
    'lastUpdated' => '1179835936',
    'message' => 'Relative URL zum Post auf dem Server (/pfad/zum/post) anstatt dem vollen Pfad (http://server/pfad/zum/post). Standard ist der volle Pfad.'
  },
  'reply.content' => {
    'lastUpdated' => '1179836089',
    'message' => 'Der Inhalt des Posts, auf den geantwortet wird.'
  },
  'reply.synopsis' => {
    'lastUpdated' => '1179836079',
    'message' => 'Die Zusammenfassung des Posts, auf den geantwortet wird. Falls keine Zusammenfassung angegeben wurde, wird versucht, eine Zusammenfassung aus dem Text der Beschreibung bis zum ^-; Marker zu generieren. Falls kein Marker gefunden werden kann, wird der Text bis zur ersten neuen Zeile benutzt.'
  },
  'reply.title' => {
    'lastUpdated' => '1179836067',
    'message' => 'Der Titel des Posts, auf den geantwortet wird.'
  },
  'reply.url' => {
    'lastUpdated' => '1179836139',
    'message' => 'URL, um auf den Post zu antworten, ohne diesen zu zitieren.'
  },
  'reply.userDefinedN' => {
    'lastUpdated' => '1179836181',
    'message' => 'Der Inhalt der benutzerdefinierten Felder des Posts, auf den geantwortet wird; N von 1 bis 5.'
  },
  'reply.withQuote.url' => {
    'lastUpdated' => '1179836225',
    'message' => 'URL, um auf diesen Post (dieser wird zitiert) zu antworten.'
  },
  'skipNotification.form' => {
    'lastUpdated' => '1269421913',
    'message' => 'Ein Feld, das es Nutzern mit entsprechenden Bearbeitungsrechten ermöglicht, die E-Mail-Benachrichtigung zu überspringen.'
  },
  'status' => {
    'lastUpdated' => '1179836252',
    'message' => 'Der Status dieses Posts: "Freigegeben", "Schwebend" oder "Archiviert".'
  },
  'sticky.form' => {
    'lastUpdated' => '1179836343',
    'message' => 'Eine Ja/Nein Schaltfläche, um den Thread auf "sticky" zu setzen. Das bedeutet, dass der Thread am Anfang des Forum Listings aufgeführt wird.'
  },
  'storageId' => {
    'lastUpdated' => '1179836395',
    'message' => 'Die Asset ID des Speicherknotens des Posts; dort werden die Anhänge aufbewahrt.'
  },
  'subscribe.form' => {
    'lastUpdated' => '1179836458',
    'message' => 'Eine Ja/Nein Schaltfläche, die es dem Benutzer erlaubt, den Thread, dem dieser Post angehört, zu abonnieren.'
  },
  'synopsis' => {
    'lastUpdated' => '1179836488',
    'message' => 'Die Zusammenfassung des Posts. Falls keine Zusammenfassung angegeben wurde, wird versucht, eine Zusammenfassung aus dem Text der Beschreibung bis zum ^-; Marker zu generieren. Falls kein Marker gefunden werden kann, wird der Text bis zur ersten neuen Zeile benutzt.'
  },
  'synopsis.form' => {
    'lastUpdated' => '1179836506',
    'message' => 'Ein Formular Feld für die Eingabe der Zusammenfassung.'
  },
  'threadId' => {
    'lastUpdated' => '1179836525',
    'message' => 'Die ID des Threads, der den Post enthält.'
  },
  'thumbnail' => {
    'lastUpdated' => '1179836551',
    'message' => 'Ein Thumbnail für diesen Anhang, falls anwendbar.'
  },
  'title' => {
    'lastUpdated' => '1179836562',
    'message' => 'Der Titel dieses Posts.'
  },
  'title.form' => {
    'lastUpdated' => '1179836639',
    'message' => 'Ein einzeiliges Formular Feld für die Eingabe des Titels. HTML wird entfernt, Makros werden deaktiviert. Benutzen Sie dieses Feld <strong>ODER</strong> title.form.textarea.'
  },
  'title.form.textarea' => {
    'lastUpdated' => '1179836712',
    'message' => 'Ein Formular Feld zur Eingabe des Titels (Text Bereich). HTML wird entfernt und Makros werden deaktiviert. Benutzen Sie dieses Feld <strong>ODER</strong> title.form.'
  },
  'title.short' => {
    'lastUpdated' => '1179836730',
    'message' => 'Der Titel des Posts, limitiert auf 30 Zeichen.'
  },
  'unsubscribeLinkText' => {
    'lastUpdated' => '1217255197',
    'message' => 'Das internationalisierte Word &quot;Unsubscribe&quot;, wird benutzt als Text für den Link zum Beenden eines Abonnements.'
  },
  'unsubscribeUrl' => {
    'lastUpdated' => '1215072909',
    'message' => 'Die URL für den User zum abbestellen.'
  },
  'url' => {
    'lastUpdated' => '1179836741',
    'message' => 'URL zum Download des Anhangs.'
  },
  'usePreview' => {
    'lastUpdated' => '1179836817',
    'message' => 'Eine Bedingung, die angibt, ob die Posts eines Threads in einer Vorschau angezeigt werden bevor sie abgeschickt (submitted) werden.'
  },
  'user.canEdit' => {
    'lastUpdated' => '1179836908',
    'message' => 'Bedingung, die wahr ist, falls der Benutzer einen neuen Post hinzufügt. Im Gegensatz um Bearbeiten eines schon existierenden Posts.'
  },
  'user.isModerator' => {
    'lastUpdated' => '1179836925',
    'message' => 'Bedingung, die anzeigt, ob der aktuelle Benuzter ein Moderator ist.'
  },
  'user.isPoster' => {
    'lastUpdated' => '1179836949',
    'message' => 'Bedingung, die wahr ist, falls der aktuelle Benutzer der Besitzer des Posts ist.'
  },
  'user.isVisitor' => {
    'lastUpdated' => '1179836969',
    'message' => 'Bedingung, die anzeigt, ob der aktuelle Benutzer ein Visitor ist.'
  },
  'userDefined1' => {
    'lastUpdated' => '1179835819',
    'message' => 'Der Wert der ersten benutzerdefinierten Variablen.'
  },
  'userDefined2' => {
    'lastUpdated' => '1179835811',
    'message' => 'Der Wert der zweiten benutzerdefinierten Variablen.'
  },
  'userDefined3' => {
    'lastUpdated' => '1238016941',
    'message' => 'Der Wert der dritten Benutzer-definierten Variablen.'
  },
  'userDefined4' => {
    'lastUpdated' => '1179835779',
    'message' => 'Der Wert der vierten benutzerdefinierten Variablen.'
  },
  'userDefined5' => {
    'lastUpdated' => '1179835768',
    'message' => 'Der Wert der fünften benutzerdefinierten Variablen.'
  },
  'userDefinedN.form' => {
    'lastUpdated' => '1179835715',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular Widget f&uuml;r eine einzelne Zeile Text.'
  },
  'userDefinedN.form.float' => {
    'lastUpdated' => '1179835700',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular Widget f&uuml;r einen float Wert.'
  },
  'userDefinedN.form.htmlarea' => {
    'lastUpdated' => '1179835685',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular Widget f&uuml;r einen WYSIWYG HTML Bereich.'
  },
  'userDefinedN.form.textarea' => {
    'lastUpdated' => '1179835658',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular Widget f&uuml;r einen Text Bereich.'
  },
  'userDefinedN.form.yesNo' => {
    'lastUpdated' => '1179835633',
    'message' => 'Für jedes der 5 benutzerdefinierten Felder ein Formular Widget f&uuml;r ein Ja/Nein Feld.'
  },
  'userId' => {
    'lastUpdated' => '1179835533',
    'message' => 'Die Benutzer ID des Besitzers des Posts.'
  },
  'userProfile.url' => {
    'lastUpdated' => '1179835516',
    'message' => 'URL zum Profil des Besitzers des Posts.'
  },
  'username' => {
    'lastUpdated' => '1179835501',
    'message' => 'Der Name des Benutzers, der den Post abgeschickt oder als letztes aktualisiert hat.'
  },
  'value' => {
    'lastUpdated' => '1193133334',
    'message' => 'Der Wert dieses metadata Feldes.'
  },
  'views' => {
    'lastUpdated' => '1179835472',
    'message' => 'Zahl, die angibt, wie oft ein Post angesehen wurde.'
  },
  'visitorName.form' => {
    'lastUpdated' => '1179835434',
    'message' => 'Ein Formular, in dem der Benutzer seinen Namen eingeben kann, sogar als Visitor.'
  }
}
;

1;
